"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _elm = _interopRequireDefault(require("highlight.js/lib/languages/elm"));
var _default = exports["default"] = _elm["default"];